@@ -1,3 +1,4 @@
+#include "Zmaxdef.h"
 c   Parameters   needed  for the Launcher.
 c
 c	(->	------------------------------------
@@ -49,15 +50,18 @@ c	(->	------------------------------------
                                    !  (for nucleus; otherwise 1).
         real*8        BaseErg      !2  See BaseTime.  The default is  1000 (GeV).
         real*8        BasePower    !2  See BaseTime.   Default is 1.0
+        character*100 UserHookc    !2  array size is MAX_USERHOOKC=5 Usage is left for the user
+        real*8        UserHookr    !2  array size is MAX_USERHOOKR=10 Usage is left for the user
+        integer       UserHooki    !2  array size is MAX USERHOOKI=10 Usage is left for the user
 
 c	<-)	-------------------------------------
 	common /Zmanagerpc/
-     *  BaseTime,  BaseErg, BasePower, Within, 
-     *  ErrorOut, Cont, InitRN(2), 
+     *  BaseTime,  BaseErg, BasePower, Within, UserHookr(MAX_USERHOOKR),
+     *  ErrorOut, Cont, InitRN(2), UserHooki(MAX_USERHOOKI),
      *  EventsInTheRun, DestEventNo(2), Hidden, TempDev, 
      *  PrevEventNo, SeedFileDev, EventNo
 
 
-	common /Zmanagerpc2/ PrimaryFile,
-     *  CutOffFile,  Job, ContFile,  
+	common /Zmanagerpc2/ UserHookc(MAX_USERHOOKC), PrimaryFile,
+     *  CutOffFile,  Job, ContFile, 
      *  SkeletonFile, SeedFile, DeadLine
