@@ -11,15 +11,16 @@ c     *****************************************************************
       implicit none
 #include  "Zglobalc.h"
 #include  "Zcode.h"
+#include  "Ztrackp.h"
 #include  "Ztrack.h"
 #include  "Ztrackv.h"
 #include  "Zheavyp.h"
 #include  "Zelemagp.h"
 #include  "Zevhnp.h"
-
+#include  "Zcmuint.h"
 c     **************************************************
 c
-      real*8 mfp, ek,  xs, et, mass, ctau
+      real*8 mfp, ek,  xs, et, mass, ctau, prob, path
 c            
 c        m.f.p (kg/m**2) = abn /xsec(mb)
 c        parameter (aira=14.5, abogn=6.02e23, abn=aira*1.e28/abogn)
@@ -96,8 +97,34 @@ c         get mean free path for collision
                call ckMinusAXsec(TargetMassN, ek, xs)
             endif
          elseif (ka .eq. kmuon) then
-c            mu is assumed to have no collision at present
             xs = smallxs
+            if(FromEpics) then
+c              muon interaction in Epics is managed within
+c              Epics so that we should skip this part
+            else
+               if(MuPr .ge. 2 .and.
+     *              TrackBefMove.p.fm.p(4) .gt. muPrEmin) then
+                  call cmuPrsmpP(TrackBefMove.p.fm.p(4), prob, path)
+                  collkgram = path * 10. ! kg/m^2
+                  call csetIntInf(collkgram, .false., 'mupair')
+                  xs =max( prob/toabn*TargetMassN/10., smallxs)
+               endif
+               if(MuBr .ge. 2 .and. 
+     *              TrackBefMove.p.fm.p(4) .gt. muBrEmin) then
+                  call cmuBrsmpP(TrackBefMove.p.fm.p(4), prob, path)
+                  collkgram = path * 10. ! kg/m^2
+                  call csetIntInf(collkgram, .false., 'mubrem')
+                  xs =max( prob/toabn*TargetMassN/10., smallxs)
+               endif
+               if(MuNI .ge. 2 .and. 
+     *              TrackBefMove.p.fm.p(4) .gt. muNEmin) then
+                  call cmuNsmpP(TrackBefMove.p.fm.p(4), prob, path)
+                  collkgram = path * 10. ! kg/m^2
+                  call csetIntInf(collkgram, .false., 'munuci')
+                  xs =max( prob/toabn*TargetMassN/10., smallxs)
+               endif
+               if(xs .ne. smallxs) goto 100 !  *********
+            endif
          elseif (ka .eq. knuc) then
             if(TrackBefMove.p.subcode .eq. antip) then
                if(ek .ne. eps) then
@@ -140,6 +167,7 @@ c             sample interaction length
          endif
       endif
       call csetIntInf(collkgram, .false., 'coll')
+ 100  continue
       end
 
 
